.. Copyright 2023 Ross J. Duff MSc 
   The copyright holder licenses this file
   to you under the Apache License, Version 2.0 (the
   "License"); you may not use this file except in compliance
   with the License.  You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing,
   software distributed under the License is distributed on an
   "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
   KIND, either express or implied.  See the License for the
   specific language governing permissions and limitations
   under the License.

========
OZI test
========

Testing and continuous devolopment.

Default Toolchain
-----------------

* Coverage.py_:
  Code coverage testing for Python.
* Hypothesis_:
  Generates simple and comprehensible examples that make your tests fail.
* pytest_:
  Scalable, fixture-based testing framework for Python.
* pytest-asyncio_:
  Automatically executes tests declared asyncronous.
* pytest-cov_:
  Code coverage checkpointing.
* pytest-tcpclient_:
  Mocked TCP client for testing.
* pytest-randomly_:
  Generates random test ordering.
* pytest-xdist_:
  Distributed testing support.


.. _Coverage.py: https://pypi.org/project/coverage
.. _Hypothesis: https://pypi.org/project/hypothesis
.. _pytest: https://pypi.org/project/pytest/
.. _pytest-asyncio: https://pypi.org/project/pytest-asyncio/
.. _pytest-cov: https://pypi.org/project/pytest-cov/
.. _pytest-tcpclient: https://pypi.org/pytest-tcpclient/
.. _pytest-randomly: https://pypi.org/project/pytest-randomly/
.. _pytest-xdist: https://pypi.org/project/pytest-xdist/